content property
Store the content that will be written to the file in a String or Future String in that variable. It is used to fill the file created by path.
Implementation
@override
String get content => '''$import
part 'app_routes.dart';
class AppPages {
AppPages._();
$_initialRoute
static final routes = [
];
}
''';